<?php
/*
Plugin Name: Paloose
Plugin URI: http://www.paloose.org/
Description: Paloose plugin provides a Cocoon like extension to Joommla! to handle XML files using XSL.
Version: 1.0.0b3
Author: Hugh Field-Richards
Author URI: http://automattic.com/wordpress-plugins/
License: GPLv2 (only the plugin, Paloose is issued under GPLV3)
Copyright: (C) 2006 - 2011 Hugh Field-Richards. All Rights Reserved
*/
/*
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// No direct access
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

class plgContentPaloose extends JPlugin
{

//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
//-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
/**
 * Constructor
 *
 * @access      protected
 * @param       object  $subject The object to observe
 * @param       array   $config  An array that holds the plugin configuration
 * @since       1.6
 */

   public function __construct( &$subject, $config )
	{
		parent::__construct( $subject, $config );
		$this->loadLanguage();
	}

   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
	/**
	 * Example prepare content method
	 *
	 * Method is called by the view
	 *
	 * @param	string	The context of the content being passed to the plugin.
	 * @param	object	The content object.  Note $inArticle->text is also available
	 * @param	object	The content params
	 * @param	int		The 'page' number
	 * @since	1.6
	 */

	public function onContentPrepare( $inContext, &$inArticle, &$params, $inLimitstart = 0 )
	{
      // simple performance check to determine whether bot should process further
      if ( JString::strpos( $inArticle->text, 'paloose' ) === false ) {
         return true;
      }

      // expression to search for: {paloose link="concerts.html" query="year=2009"}
   	$regex = '#{paloose\s+link=\"([^\"]+)\"\s+query=\"([^\"]+)\"}#iU';
   	
      // Check whether plugin has been unpublished
      if ( !$this->params->get( 'enabled', 1 ) ) {
         $inArticle->text = preg_replace( $regex, '', $inArticle->text );
         return true;
      }
              
      // Find all instances of plugin and put in $matches
      preg_match_all( $regex, $inArticle->text, $matches );
      // Number of plugins
      $count = count( $matches[0] );

      // plugin only processes if there are any instances of the plugin in the text
      if ( $count ) {
         // Get plugin parameters
         $this->processText( $inArticle, $matches, $count, $this->params );
      }
      return true;
	}
	
   //-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-* 
	/**
	 * Process the text
	 */

	protected function processText(  &$inArticle, &$inMatches, $inCount, &$params )
	{
		// Now set all the Paloose constants. These are all gathered from the options page where they
      // are declared. Any not declared there will be set eventually to the defaults by the Paloose system.
      define( 'PALOOSE_DIRECTORY', $this->params->get( 'palooseDirectory' ) );
      define( 'PALOOSE_LIB_DIRECTORY', PALOOSE_DIRECTORY . '/lib' );
      define( 'PALOOSE_SITE_ROOT_DIRECTORY', $this->params->get( 'siteRootDirectory' ) );
      define( 'PALOOSE_LOGGER_CONFIGURATION_FILE', $this->params->get( 'loggerConfig' ) );
      define( 'PALOOSE_LOG4PHP_DIRECTORY', $this->params->get( 'log4phpDir' ) );
      define( 'PALOOSE_CACHE_DIR', $this->params->get( 'CACHE_DIR' ) );
      define( 'PALOOSE_ROOT_SITEMAP', $this->params->get( 'rootSiteMap' ) );
      define( 'PALOOSE_USER_EXCEPTION_PAGE', $this->params->get( 'userExceptionPage' ) );
      define( 'PALOOSE_USER_EXCEPTION_TRANSFORM', $this->params->get( 'userExceptionTransform' ) );
      define( 'PALOOSE_USER_EXCEPTION_STYLE', $this->params->get( 'userExceptionStyle' ) );
      define( 'PALOOSE_INTERNAL_EXCEPTION_PAGE', $this->params->get( 'internalExceptionPage' ) );
      define( 'PALOOSE_INTERNAL_EXCEPTION_TRANSFORM', $this->params->get( 'internalExceptionTransform' ) );
      define( 'PALOOSE_INTERNAL_EXCEPTION_STYLE', $this->params->get( 'internalExceptionStyle' ) );

      // The following are always fixed
      define( 'PALOOSE_SITEMAP_NAMESPACE', 'http://apache.org/cocoon/sitemap/1.0' );
      define( 'PALOOSE_SOURCE_NAMESPACE', 'http://apache.org/cocoon/source/1.0' );
      define( 'PALOOSE_DIR_NAMESPACE', 'http://apache.org/cocoon/directory/2.0' );
      define( 'PALOOSE_SQL_QUERY_NAMESPACE', 'http://apache.org/cocoon/SQL/2.0' );
      define( 'PALOOSE_I18N_NAMESPACE', 'http://apache.org/cocoon/i18n/2.1' );
      define( 'PALOOSE_PAGE_HIT_TRANSFORM', 'resource://resources/transforms/PageHit.xsl' );
      define( 'PALOOSE_NAMESPACE', 'http://www.paloose.org/schemas/Paloose/1.0' );

      // These last two are very important and tell Paloose that it is working as a client
      // to WordPress rather than as a server in its own right. There is no opportunity to reset
      // these on the options page (obviously).
      define( 'PALOOSE_CLIENT', 'yes' );
      define( 'PALOOSE_SESSIONS_REQUIRED', 'no' );
      
      ini_set( 'track_errors', '1' );
      require_once( PALOOSE_DIRECTORY . '/lib/Paloose.php' );
      $paloose = new Paloose();
      
      for ( $i = 0; $i < $inCount; $i++ ) {
         $matchedString = $inMatches[0][$i];
         $linkString = $inMatches[1][$i];
         $queryString = $inMatches[2][$i];

         $paloose->run( $linkString, $queryString );
         $palooseReturnString = Environment::$gClientBuffer;

         // Remove the matched text and replace with Paloose generated output
         $inArticle->text = str_replace( $matchedString, $palooseReturnString, $inArticle->text );
      } // pool 
      unset( $paloose );
      
   } // function processText

}

?>
